@@ -18,7 +18,7 @@ def run_query(query_id):
     base = request.base_url.replace(
         f"/doubleclickbidmanager/v1.1/query/{query_id}", "")
     _, status_code = Report(query_id=query_id, base_url=base).run()
-    return None, status_code
+    return {}, status_code
 
 
 @reporting_blueprint.route('/doubleclickbidmanager/v1.1/query', methods=["POST"])
